"""
This type stub file was generated by pyright.
"""

from typing import Optional

def caching_resolver(*, timeout: Optional[int] = ..., cache=...): # -> Resolver:
    ...

def validate_email_deliverability(domain: str, domain_i18n: str, timeout: Optional[int] = ..., dns_resolver=...): # -> dict[str, str] | dict[str, Any]:
    ...




# ozi/_i18l.py
# Part of the OZI Project, under the Apache License v2.0 with LLVM Exceptions.
# See LICENSE.txt for license information.
# SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
"""Internationalization utilities."""
from __future__ import annotations

import locale
from string import Template
from typing import TYPE_CHECKING
from typing import Any

from ozi_core._locales import data

if TYPE_CHECKING:  # pragma: no cover
    import sys

    if sys.version_info >= (3, 11):
        from typing import Self
    elif sys.version_info < (3, 11):
        from typing_extensions import Self

_LOCALE = locale.getlocale()[0]


class Translation:

    __slots__ = ('_locale', 'data')

    def __init__(self: Self) -> None:
        self.data = data
        self._locale = (
            _LOCALE[:2] if _LOCALE is not None and _LOCALE[:2] in self.data else 'en'
        )

    @property
    def locale(self: Self) -> str | Any:  # pragma: no cover
        return self._locale

    @locale.setter
    def locale(self: Self, loc: str) -> None:  # pragma: no cover
        if loc in self.data:
            self._locale = loc
        else:
            print('Invalid locale')

    def __call__(self: Self, _key: str, **kwargs: str) -> str:  # pragma: no cover
        if self.locale not in self.data:
            return _key
        text = self.data[self.locale].get(_key, _key)
        if text is None:
            return ''
        return Template(text).safe_substitute(**kwargs)


TRANSLATION = Translation()



"""
This type stub file was generated by pyright.
"""

"""SPDX standard metadata parser expression grammars, with support for :pep:`639` keys."""
user_defined_license = ...
spdx_license_expression = ...



"""
This type stub file was generated by pyright.
"""

from pathlib import Path
from typing import TYPE_CHECKING
from typing import AnyStr
from typing import Literal

from jinja2 import Environment

"""Rendering utilities for the OZI project templates.
"""
if TYPE_CHECKING:
    ...
def find_user_template(target: str, file: str, fix: str) -> str | None:
    """Find a user-defined project template file e.g. :file:`{target}/templates/{fix}/{file}`.

    :param target: path to an OZI project directory
    :type target: Path
    :param file: filename
    :type file: str
    :param fix: template directory fix path
    :type fix: str
    :return: a user-defined template as a string
    :rtype: str | None
    """
    ...

def map_to_template(fix: (Literal['child', 'github_workflows', 'root', 'source', 'subprojects', 'templates', 'test',] | AnyStr), filename: str) -> str:
    """Map an appropriate template for an ozi-fix mode and filename.

    .. versionadded:: 1.5

    :param fix: ozi-fix mode setting
    :type fix: AnyStr
    :param filename: name with file extension
    :type filename: str
    :return: template path
    :rtype: str
    """
    ...

def build_file(env: Environment, fix: (Literal['child', 'github_workflows', 'root', 'source', 'subprojects', 'templates', 'test',] | AnyStr), path: Path, user_template: str | None, **kwargs: str) -> None:
    """Render project file based on OZI templates.

    .. versionadded:: 1.5

    :param env: rendering environment
    :type env: Environment
    :param fix: ozi-fix setting
    :type fix: AnyStr
    :param path: full path of file to be rendered
    :type path: Path
    :param user_template: path to a user template to extend
    :type user_template: str | None
    """
    ...

def build_child(env: Environment, parent: str, child: Path) -> None:
    """Add a child directory to a parent in an existing OZI-style project.

    :param env: the OZI project file rendering environment
    :type env: jinja2.Environment
    :param parent: existing directory name in project
    :type parent: str
    :param child: path to a new child directory
    :type child: Path
    """
    ...

class RenderedContent:
    def __init__(self, env: Environment, target: Path, name: str, ci_provider: str, readme_type: str) -> None:
        """OZI new project content to render.

        .. versionadded:: 1.15.2

        :param target: project root path
        :type target: Path
        :param name: project name
        :type name: str
        :param ci_provider: :term:`CI` provider setting
        :type ci_provider: str
        :param readme_type: the README file extension
        :type readme_type: str
        """
        ...
    
    def render(self) -> None:
        """Render the project."""
        ...
    


def render_ci_files_set_user(env: Environment, target: Path, ci_provider: str) -> str:
    """Render :term:`CI` files based on the ci_provider for target in env.

    :param env: the OZI project file rendering environment
    :type env: jinja2.Environment
    :param target: directory path to render the project
    :type target: Path
    :param ci_provider: the name of the project continuous integration provider
    :type ci_provider: str
    :return: the ci_user of the target repository for the continuous integration provider
    :rtype: str
    """
    ...

def render_project_files(env: Environment, target: Path, name: str) -> None:
    """Render the primary new project files(excluding CI).

    :param env: the OZI project file rendering environment
    :type env: jinja2.Environment
    :param target: directory path to render the project
    :type target: Path
    :param name: the canonical project name (without normalization)
    :type name: str
    """
    ...




# ozi/fix/__init__.py
# Part of the OZI Project, under the Apache License v2.0 with LLVM Exceptions.
# See LICENSE.txt for license information.
# SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
"""ozi-fix: Project fix script that outputs a meson rewriter JSON array."""
from __future__ import annotations

import json
import os
from pathlib import Path
from typing import TYPE_CHECKING
from typing import NoReturn

from ozi_spec import METADATA
from ozi_templates import load_environment
from ozi_templates.filter import underscorify  # pyright: ignore
from tap_producer import TAP

from ozi_core.fix.missing import report
from ozi_core.fix.parser import parser
from ozi_core.fix.rewrite_command import Rewriter
from ozi_core.new.validate import valid_copyright_head

if TYPE_CHECKING:  # pragma: no cover
    from argparse import Namespace

    from jinja2 import Environment


def _setup(project: Namespace) -> tuple[Namespace, Environment]:  # pragma: no cover
    TAP.version(14)
    project.target = Path(os.path.relpath(os.path.join('/', project.target), '/')).absolute()
    if not project.target.exists():
        TAP.bail_out(f'target: {project.target} does not exist.')
    elif not project.target.is_dir():
        TAP.bail_out(f'target: {project.target} is not a directory.')
    project.add.remove('ozi.phony')
    project.add = list(set(project.add))
    project.remove.remove('ozi.phony')
    project.remove = list(set(project.remove))
    env = load_environment(vars(project), METADATA.asdict())
    return project, env


def main() -> NoReturn:  # pragma: no cover
    """Main ozi.fix entrypoint."""
    project = parser.parse_args()
    project.missing = project.fix == 'missing' or project.fix == 'm'
    match [project.missing, project.strict]:
        case [True, False]:
            project, _ = _setup(project)
            name, *_ = report(project.target)
            TAP.end()
        case [False, _]:
            with TAP() as t:
                with t.subtest():  # pyright: ignore
                    project, env = _setup(project)
                    name, *_ = report(project.target)
                    project.name = underscorify(name)
                    project.license_file = 'LICENSE.txt'
                    project.copyright_head = valid_copyright_head(
                        project.copyright_head, name, project.license_file
                    )
                    rewriter = Rewriter(str(project.target), project.name, project.fix, env)
                    rewriter += project.add
                    rewriter -= project.remove
                if len(project.add) > 0 or len(project.remove) > 0:
                    print(
                        json.dumps(rewriter.commands, indent=4 if project.pretty else None)
                    )
                else:
                    parser.print_help()
        case [True, True]:
            with TAP.strict():  # pyright: ignore
                project, _ = _setup(project)
                name, *_ = report(project.target)
            TAP.end()
        case [_, _]:
            TAP.bail_out('Name discovery failed.')
    exit(0)



"""
This type stub file was generated by pyright.
"""

"""This script generates locales based on ozi_core/data files."""
def load_locale_data() -> dict[str, str]:
    ...

if __name__ == '__main__':
    text = ...



"""This script generates locales based on ozi_core/data files."""

import glob  # pragma: no cover
import os  # pragma: no cover
import pprint  # pragma: no cover
from pathlib import Path  # pragma: no cover

import yaml  # pragma: no cover


def load_locale_data() -> dict[str, str]:  # pragma: no cover
    data = {}
    files = glob.glob(os.path.join(Path(__file__).parent / 'data', '*.yml'))
    for f in files:
        loc = os.path.splitext(os.path.basename(f))[0]
        with open(f, 'r', encoding='utf8') as fh:
            data[loc] = yaml.safe_load(fh)
    return data


if __name__ == '__main__':
    text = """# This file was generated by ozi_core.generate_locales DO NOT EDIT
data: dict[str, dict[str, str | None] | dict[str, str]] = {locales}"""
    print(
        text.format(
            locales=pprint.pformat(load_locale_data(), width=72).replace('{', '{\n', 1)
        ),
        file=open(Path(__file__).parent / '_locales.py', 'w', encoding='utf8'),
    )



"""
``ozi-new`` interactive prompts
"""

from __future__ import annotations

import os
import sys
from typing import TYPE_CHECKING
from unittest.mock import Mock

if sys.platform != 'win32':
    import curses
else:
    curses = Mock()
    curses.tigetstr = lambda x: b''
    curses.setupterm = lambda: None

from ozi_core.new.interactive.project import Project

if TYPE_CHECKING:
    from argparse import Namespace


def interactive_prompt(project: Namespace) -> list[str]:  # pragma: no cover
    curses.setupterm()
    e3 = curses.tigetstr('E3') or b''
    clear_screen_seq = curses.tigetstr('clear') or b''
    os.write(sys.stdout.fileno(), e3 + clear_screen_seq)
    project_prompt = Project(check_package_exists=project.check_package_exists)
    return project_prompt()



from prompt_toolkit.styles import Style  # pyright: ignore

_style_dict = {
    'dialog': 'bg:#030711 fg:#030711',
    'dialog.body checkbox-list': '#e1e7ef',
    'dialog.body checkbox': '#e1e7ef',
    'dialog.body checkbox-selected': 'bg:#192334',
    'dialog.body checkbox-checked': '#e1e7ef',
    'dialog.body radio-list': '#e1e7ef',
    'dialog.body radio': '#e1e7ef',
    'dialog.body radio-selected': 'bg:#192334',
    'dialog.body radio-checked': '#e1e7ef',
    'button': '#e1e7ef',
    'dialog label': '#e1e7ef',
    'frame.border': '#192334',
    'dialog.body': 'bg:#030711',
    'dialog shadow': 'bg:#192334',
}

_style = Style.from_dict(_style_dict)
